@@ -1,11 +1,12 @@
 from itertools import product
-from typing import Tuple
+from json import loads
 
 from PySide6.QtCore import QPoint, QRect
 from PySide6.QtGui import QBrush, QColor, QImage, QPainter, QPen, Qt
 
-from foundry import data_dir
+from foundry import data_dir, namespace_path
 from foundry.core.graphics_set.GraphicsSet import GraphicsSet
+from foundry.core.namespace import Namespace, generate_namespace
 from foundry.core.palette import NESPalette
 from foundry.core.palette.PaletteGroup import MutablePaletteGroup
 from foundry.game.File import ROM
@@ -25,7 +26,7 @@ from foundry.game.gfx.objects.ObjectLike import (
 )
 from foundry.game.level.Level import Level
 from foundry.gui.AutoScrollDrawer import AutoScrollDrawer
-from foundry.gui.settings import SETTINGS
+from foundry.gui.settings import UserSettings
 from foundry.smb3parse.constants import OBJ_AUTOSCROLL, TILESET_BACKGROUND_BLOCKS
 from foundry.smb3parse.levels import LEVEL_MAX_LENGTH
 from foundry.smb3parse.objects.object_set import (
@@ -35,6 +36,16 @@ from foundry.smb3parse.objects.object_set import (
     ICE_OBJECT_SET,
 )
 
+
+def load_namespace() -> Namespace:
+    with open(str(namespace_path)) as f:
+        return generate_namespace(loads(f.read()))
+
+
+namespace = load_namespace()
+level_images = namespace.children["graphics"].children["level_images"]
+
+
 png = QImage(str(data_dir / "gfx.png"))
 png.convertTo(QImage.Format_RGB888)
 
@@ -58,28 +69,28 @@ def _load_from_png(x: int, y: int):
     return image
 
 
-FIRE_FLOWER = _load_from_png(16, 53)
-LEAF = _load_from_png(17, 53)
-NORMAL_STAR = _load_from_png(18, 53)
-CONTINUOUS_STAR = _load_from_png(19, 53)
-MULTI_COIN = _load_from_png(20, 53)
-ONE_UP = _load_from_png(21, 53)
-COIN = _load_from_png(22, 53)
-VINE = _load_from_png(23, 53)
-P_SWITCH = _load_from_png(24, 53)
-SILVER_COIN = _load_from_png(25, 53)
-INVISIBLE_COIN = _load_from_png(26, 53)
-INVISIBLE_1_UP = _load_from_png(27, 53)
+FIRE_FLOWER = level_images["fire_flower"].drawable.image()
+LEAF = level_images["leaf"].drawable.image()
+NORMAL_STAR = level_images["star"].drawable.image()
+CONTINUOUS_STAR = level_images["star_continuous"].drawable.image()
+MULTI_COIN = level_images["coins_multiple"].drawable.image()
+ONE_UP = level_images["extra_life"].drawable.image()
+COIN = level_images["coin"].drawable.image()
+VINE = level_images["vine"].drawable.image()
+P_SWITCH = level_images["p_switch"].drawable.image()
+SILVER_COIN = level_images["coin_silver"].drawable.image()
+INVISIBLE_COIN = level_images["coin_invisible"].drawable.image()
+INVISIBLE_1_UP = level_images["coin_extra_life"].drawable.image()
 
-NO_JUMP = _load_from_png(32, 53)
-UP_ARROW = _load_from_png(33, 53)
-DOWN_ARROW = _load_from_png(34, 53)
-LEFT_ARROW = _load_from_png(35, 53)
-RIGHT_ARROW = _load_from_png(36, 53)
+NO_JUMP = level_images["no_jump"].drawable.image()
+UP_ARROW = level_images["up_arrow"].drawable.image()
+DOWN_ARROW = level_images["down_arrow"].drawable.image()
+LEFT_ARROW = level_images["left_arrow"].drawable.image()
+RIGHT_ARROW = level_images["right_arrow"].drawable.image()
 
-ITEM_ARROW = _load_from_png(53, 53)
+ITEM_ARROW = level_images["item_arrow"].drawable.image()
 
-EMPTY_IMAGE = _load_from_png(0, 53)
+EMPTY_IMAGE = level_images["empty"].drawable.image()
 
 
 SPECIAL_BACKGROUND_OBJECTS = [
@@ -116,16 +127,8 @@ def _block_from_index(block_index: int, level: Level) -> Block:
 
 
 class LevelDrawer:
-    def __init__(self):
-        self.draw_jumps = False
-        self.draw_grid = False
-        self.draw_expansions = False
-        self.draw_mario = False
-        self.draw_jumps_on_objects = True
-        self.draw_items_in_blocks = True
-        self.draw_invisible_items = True
-        self.draw_autoscroll = True
-        self.transparency = False
+    def __init__(self, user_settings: UserSettings):
+        self.user_settings = user_settings
 
         self.block_length = Block.WIDTH
 
@@ -150,19 +153,19 @@ class LevelDrawer:
 
         self._draw_overlays(painter, level)
 
-        if self.draw_expansions:
+        if self.user_settings.draw_expansion:
             self._draw_expansions(painter, level)
 
-        if self.draw_mario:
+        if self.user_settings.draw_mario:
             self._draw_mario(painter, level)
 
-        if self.draw_jumps:
+        if self.user_settings.draw_jumps:
             self._draw_jumps(painter, level)
 
-        if self.draw_grid:
+        if self.user_settings.draw_grid:
             self._draw_grid(painter, level)
 
-        if self.draw_autoscroll:
+        if self.user_settings.draw_autoscroll:
             self._draw_auto_scroll(painter, level)
 
     def _draw_background(self, painter: QPainter, level: Level):
@@ -261,9 +264,9 @@ class LevelDrawer:
                     level_object._draw_block(painter, block_index, x, y, self.block_length, False, blocks=blocks)
             else:
                 if isinstance(level_object, LevelObject):
-                    level_object.draw(painter, self.block_length, self.transparency, blocks=blocks)
+                    level_object.draw(painter, self.block_length, self.user_settings.block_transparency, blocks=blocks)
                 else:
-                    level_object.draw(painter, self.block_length, self.transparency)
+                    level_object.draw(painter, self.block_length, self.user_settings.block_transparency)
 
             if level_object.selected:
                 painter.save()
@@ -279,22 +282,30 @@ class LevelDrawer:
         painter.save()
 
         for level_object in level.get_all_objects():
+            pos = level_object.get_rect(self.block_length).topLeft()
+            rect = level_object.get_rect(self.block_length)
+
+            for overlay in level_object.definition.get_overlays():
+                drawable = overlay.drawable
+                painter.drawImage(
+                    drawable.point_offset.x + pos.x() * self.block_length,
+                    drawable.point_offset.y + pos.y() * self.block_length,
+                    drawable.image(self.block_length),
+                )
+
             name = level_object.name.lower()
 
             # only handle this specific enemy item for now
             if isinstance(level_object, EnemyObject) and "invisible door" not in name:
                 continue
 
-            pos = level_object.get_rect(self.block_length).topLeft()
-            rect = level_object.get_rect(self.block_length)
-
             # invisible coins, for example, expand and need to have multiple overlays drawn onto them
             # set true by default, since for most overlays it doesn't matter
             fill_object = True
 
             # pipe entries
             if "pipe" in name and "can go" in name:
-                if not self.draw_jumps_on_objects:
+                if not self.user_settings.draw_jump_on_objects:
                     continue
 
                 fill_object = False
@@ -357,7 +368,7 @@ class LevelDrawer:
 
             # "?" - blocks, note blocks, wooden blocks and bricks
             elif "'?' with" in name or "brick with" in name or "bricks with" in name or "block with" in name:
-                if not self.draw_items_in_blocks:
+                if not self.user_settings.draw_items_in_blocks:
                     continue
 
                 pos.setY(pos.y() - self.block_length)
@@ -389,7 +400,7 @@ class LevelDrawer:
                 painter.drawImage(arrow_pos, ITEM_ARROW.scaled(self.block_length, self.block_length))
 
             elif "invisible" in name:
-                if not self.draw_invisible_items:
+                if not self.user_settings.draw_invisible_items:
                     continue
 
                 if "coin" in name:
@@ -400,7 +411,7 @@ class LevelDrawer:
                     image = EMPTY_IMAGE
 
             elif "silver coins" in name:
-                if not self.draw_invisible_items:
+                if not self.user_settings.draw_invisible_items:
                     continue
 
                 image = SILVER_COIN
@@ -425,7 +436,7 @@ class LevelDrawer:
         painter.restore()
 
     @staticmethod
-    def _object_in_jump_area(level: Level, pos: Tuple[int, int]):
+    def _object_in_jump_area(level: Level, pos: tuple[int, int]):
         for jump in level.jumps:
             jump_rect = jump.get_rect(1, level.is_vertical)
 
@@ -439,7 +450,7 @@ class LevelDrawer:
             if level_object.selected:
                 painter.drawRect(level_object.get_rect(self.block_length))
 
-            if self.draw_expansions:
+            if self.user_settings.draw_expansion:
                 painter.save()
 
                 painter.setPen(Qt.NoPen)
@@ -464,7 +475,7 @@ class LevelDrawer:
 
         x_offset = 32 * level.start_action
         MARIO_POWERUP_Y_OFFSETS = [0, 0x20, 0x60, 0x40, 0xC0, 0xA0, 0x80, 0x60, 0xC0]
-        y_offset = MARIO_POWERUP_Y_OFFSETS[SETTINGS["default_powerup"]]
+        y_offset = MARIO_POWERUP_Y_OFFSETS[self.user_settings.default_powerup]
 
         mario_cutout = mario_actions.copy(QRect(x_offset, y_offset, 32, 32)).scaled(
             2 * self.block_length, 2 * self.block_length
