@@ -1,5 +1,3 @@
-from typing import Optional
-
 from attr import attrs
 from PySide6.QtCore import Signal, SignalInstance
 from PySide6.QtGui import QCloseEvent, Qt
@@ -15,6 +13,7 @@ from PySide6.QtWidgets import (
 )
 
 from foundry import icon
+from foundry.core.geometry import Point
 from foundry.core.palette.Palette import MutablePalette, MutablePaletteProtocol
 from foundry.core.palette.PaletteGroup import (
     MutablePaletteGroup,
@@ -31,7 +30,6 @@ from foundry.core.player_animations.util import (
     load_power_up_palettes,
     save_player_animations_to_rom,
 )
-from foundry.core.point.Point import Point
 from foundry.core.sprites import SPRITE_SIZE
 from foundry.core.sprites.Sprite import Sprite, SpriteProtocol
 from foundry.core.sprites.SpriteGroup import SpriteGroup, SpriteGroupProtocol
@@ -69,9 +67,9 @@ class PlayerViewerModel:
         cls,
         is_mario: bool = True,
         power_up: int = 0,
-        power_up_offsets: Optional[list[int]] = None,
-        palette_group: Optional[MutablePaletteGroupProtocol] = None,
-        animations: Optional[list[PlayerAnimation]] = None,
+        power_up_offsets: list[int] | None = None,
+        palette_group: MutablePaletteGroupProtocol | None = None,
+        animations: list[PlayerAnimation] | None = None,
     ):
         return cls(
             is_mario,
@@ -106,7 +104,7 @@ class PlayerViewerModel:
         page_offset_bytes = bytearray()
         for animation in self.animations:
             ani_bytes, page_bytes = animation.to_bytes()
-            ani_bytes = bytearray([i + 1 for i in ani_bytes])
+            ani_bytes = bytearray(i + 1 for i in ani_bytes)
             animation_bytes += ani_bytes
             page_offset_bytes += page_bytes
 
@@ -127,20 +125,20 @@ class PlayerViewerController(CustomChildWindow):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         title: str = "Player Viewer",
         is_mario: bool = True,
         power_up: int = 0,
-        power_up_offsets: Optional[list[int]] = None,
-        palette_group: Optional[MutablePaletteGroupProtocol] = None,
-        animations: Optional[list[PlayerAnimation]] = None,
+        power_up_offsets: list[int] | None = None,
+        palette_group: MutablePaletteGroupProtocol | None = None,
+        animations: list[PlayerAnimation] | None = None,
     ):
         super().__init__(parent, title)
 
         self.model = PlayerViewerModel.from_rom(is_mario, power_up, power_up_offsets, palette_group, animations)
         self.view = PlayerViewerView(self, self.sprite_groups)
         self.undo_controller = UndoController(self.model.to_bytes())
-        self.frame_editor: Optional[PlayerFrameEditor] = None
+        self.frame_editor: PlayerFrameEditor | None = None
         self.frame_editor_index = 0
         self.setCentralWidget(self.view)
         self.toolbar = QToolBar(self)
@@ -152,10 +150,10 @@ class PlayerViewerController(CustomChildWindow):
         self.view.mouse_moved_over_widget.connect(self._on_mouse_move)
         self.view.clicked.connect(self._show_player_frame_editor)
 
-        self.undo_action = self.toolbar.addAction(icon("rotate-ccw.svg"), "Undo Action")
-        self.redo_action = self.toolbar.addAction(icon("rotate-cw.svg"), "Redo Action")
-        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.svg"), "Zoom Out")
-        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.svg"), "Zoom In")
+        self.undo_action = self.toolbar.addAction(icon("rotate-ccw.png"), "Undo Action")
+        self.redo_action = self.toolbar.addAction(icon("rotate-cw.png"), "Redo Action")
+        self.zoom_out_action = self.toolbar.addAction(icon("zoom-out.png"), "Zoom Out")
+        self.zoom_in_action = self.toolbar.addAction(icon("zoom-in.png"), "Zoom In")
 
         self.powerup_combo_box = QComboBox()
         for (name, x, y) in POWERUPS:
@@ -386,7 +384,7 @@ class PlayerViewerView(QWidget):
 
     def __init__(
         self,
-        parent: Optional[QWidget],
+        parent: QWidget | None,
         sprite_groups: list[SpriteGroupProtocol],
         zoom: int = 2,
     ):
