@@ -5,7 +5,7 @@ SPINNER_MAX_VALUE = 0xFF_FF_FF  # arbitrary; 16,7 MB
 
 class Spinner(QSpinBox):
     def __init__(self, parent, maximum=SPINNER_MAX_VALUE, base=16):
-        super(Spinner, self).__init__(parent)
+        super().__init__(parent)
 
         self.setRange(0, maximum)
         self.setDisplayIntegerBase(base)
